@@ -67,7 +67,7 @@ class GeocodeAddresses(ExecuteFunction):
 
     def execute_function(self, data_set):
 
-        if data_set.user_is_previewing_app() and len(data_set.query(InputAddress).all()) > 20:
+        if len(data_set.query(InputAddress).all()) > 20:
             data_set.send_progress_message("You can only geocode up to 20 locations using the free version of this app")
         else:
             data_set.send_progress_message("Deleting old results")
