@@ -30,7 +30,9 @@ class Shop(DataSetMixin):
     longitude = Column(Float, nullable=False)
     demand = Column(Integer, nullable=False)
 
-    __table_args__ = (UniqueConstraint('data_set_id', 'name'),)
+    @classmethod
+    def get_table_args(cls):
+        return (UniqueConstraint('data_set_id', 'name'),)
 
 
 class Plant(DataSetMixin):
@@ -42,8 +44,10 @@ class Plant(DataSetMixin):
 
     flows = relationship('Flow', cascade='all')  # See SQLAlchemy documentation on relationship. (String used for class name as not yet defined here)
 
-    __table_args__ = (UniqueConstraint('data_set_id', 'name'),)
-
+    @classmethod
+    def get_table_args(cls):
+        return (UniqueConstraint('data_set_id', 'name'),)
+    
 
 class Flow(DataSetMixin):
     plant_name = Column(Text, nullable=False)
@@ -53,10 +57,12 @@ class Flow(DataSetMixin):
     shop = relationship(Shop)
     plant = relationship(Plant)
 
-    __table_args__ = (
-        ForeignKeyConstraint(['shop_name', 'data_set_id'], ['shop.name', 'shop.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['plant_name', 'data_set_id'], ['plant.name', 'plant.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
-    )
+    @classmethod
+    def get_table_args(cls):
+        return (
+            ForeignKeyConstraint(['shop_name', 'data_set_id'], ['shop.name', 'shop.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['plant_name', 'data_set_id'], ['plant.name', 'plant.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
+        )
 
 
 class KMLMapInput(KMLMap):
@@ -202,7 +208,7 @@ class MyFacilityLocationSolverApp(AppWithDataSets):
             determine it's catchment, or just want to know how good your current hub locations are?</p>
             <p>Do you have depot locations for staff which service a large geographic area? Are you thinking of relocating or building a new depot?</p>
             <p>Are you looking to install telecommunications equipment? Want to determine the optimal location to minimise overall traffic distance?</p>
-            <p>Are you looking to design territories for salesman? Brining on a new salesman and want to determine how the new catchments will stack up?</p>
+            <p>Are you looking to design territories for salesman? Bringing on a new salesman and want to determine how the new catchments will stack up?</p>
             <p>Want to view the answer on a map, and download it as a KML file to share with colleagues?</p>
             <p>This app might be what you are looking for! Sign up and give it a go. 
             <p>Need help or wish this app had more features, contact us at <b>info@tropofy.com</b> to see if we can help</p>''',
